@@ -154,7 +154,11 @@ class GitHubAsyncRESTClient(AbstractAsyncContextManager):
         next_url = _get_next_url(response)
 
         while next_url:
-            response = await self.get(next_url, params=params)
+            # Workaround for https://github.com/encode/httpx/issues/3433
+            new_params = (
+                httpx.URL(next_url).params.merge(params) if params else None
+            )
+            response = await self.get(next_url, params=new_params)
 
             yield response
 
