@@ -1,33 +1,20 @@
-# Copyright (C) 2020-2022 Greenbone AG
+# SPDX-FileCopyrightText: 2020-2023 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from enum import Enum
 from typing import Optional
 
+from pontos.enum import StrEnum
 from pontos.git import Git, GitError
 from pontos.terminal import Terminal
-from pontos.version import Version, VersionCalculator
-from pontos.version.errors import VersionError
+from pontos.version import Version, VersionCalculator, VersionError
 
 DEFAULT_TIMEOUT = 1000
 DEFAULT_CHUNK_SIZE = 4096
 
 
-class ReleaseType(Enum):
+class ReleaseType(StrEnum):
     """
     Type of the release. Used to determine the next release version.
 
@@ -140,3 +127,15 @@ def get_next_release_version(
         return calculator.next_release_candidate_version(last_release_version)
 
     raise VersionError(f"Unsupported release type {release_type.value}.")
+
+
+def repository_split(repository: str) -> tuple[str, str]:
+    """
+    Split a GitHub repository (owner/name) into a space, project tuple
+    """
+    splitted_repo = repository.split("/")
+    if len(splitted_repo) != 2:
+        raise ValueError(
+            f"Invalid repository {repository}. Format must be " "owner/name."
+        )
+    return splitted_repo[0], splitted_repo[1]
